@@ -1,6 +1,6 @@
 /*
     MIDI Sequencer C++ library
-    Copyright (C) 2006-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2023, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -704,6 +704,19 @@ SysExEvent* SysExEvent::clone() const
     return new SysExEvent(&m_event);
 }
 
+/**
+ * Assignment operator.
+ * @param other Another SysExEvent object reference
+ * @return pointer to this object
+ */
+SysExEvent &SysExEvent::operator=(const SysExEvent &other)
+{
+    m_event = other.m_event;
+    m_data = other.m_data;
+    snd_seq_ev_set_sysex(&m_event, m_data.size(), m_data.data());
+    return *this;
+}
+
 /**
  * Default constructor
  */
@@ -783,6 +796,21 @@ TextEvent* TextEvent::clone() const
     return new TextEvent(&m_event);
 }
 
+/**
+ * Assignment operator.
+ * @param other Another TextEvent object reference
+ * @return pointer to this object
+ */
+TextEvent &TextEvent::operator=(const TextEvent &other)
+{
+    m_event = other.m_event;
+    m_data = other.m_data;
+    m_textType = other.getTextType();
+    snd_seq_ev_set_variable(&m_event, m_data.size(), m_data.data());
+    setSequencerType(SND_SEQ_EVENT_USR_VAR0);
+    return *this;
+}
+
 /**
  * Constructor
  * @param type The event's type
