@@ -193,14 +193,14 @@ void SequencerOutputThread::run()
             }
             if (stopRequested()) {
                 m_Queue->clear();
-                emit playbackStopped();
+                Q_EMIT playbackStopped();
             } else {
                 drainOutput();
                 syncOutput();
                 if (stopRequested())
-                    emit playbackStopped();
+                    Q_EMIT playbackStopped();
                 else
-                    emit playbackFinished();
+                    Q_EMIT playbackFinished();
             }
             m_Queue->stop();
         } catch (...) {
