@@ -56,8 +56,9 @@ public:
     void close();
     void initialize(QSettings* settings);
     void setMIDIThruDevice(MIDIOutput* device);
+    void writeSettings(QSettings *settings);
 
-public slots:
+public Q_SLOTS:
     void processIncomingMessages();
 };
 
