@@ -55,7 +55,7 @@ namespace drumstick { namespace rt {
         virtual void close() override;
         virtual MIDIConnection currentConnection() override;
 
-    public slots:
+    public Q_SLOTS:
         virtual void sendNoteOff(int chan, int note, int vel) override;
         virtual void sendNoteOn(int chan, int note, int vel) override;
         virtual void sendKeyPressure(int chan, int note, int value) override;
@@ -66,6 +66,8 @@ namespace drumstick { namespace rt {
         virtual void sendSysex(const QByteArray &data) override;
         virtual void sendSystemMsg(const int status) override;
 
+        void writeSettings(QSettings *settings);
+
     private:
         class NetMIDIOutputPrivate;
         NetMIDIOutputPrivate * const d;
