@@ -1,6 +1,6 @@
 /*
     Drumstick RT (realtime MIDI In/Out)
-    Copyright (C) 2009-2022 Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2009-2023 Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -120,7 +120,12 @@ namespace drumstick { namespace rt {
         QStringList libs;
         libs << "../lib/";
     #if defined(LIBSUFFIX)
-        libs << QString("../%1/").arg(QT_STRINGIFY(LIBSUFFIX));
+        QString libextra(QT_STRINGIFY(LIBSUFFIX));
+        if (QDir::isAbsolutePath(libextra)) {
+            d->appendDir( libextra + QDir::separator() + QSTR_DRUMSTICK, result );
+        } else {
+            libs << QString("../%1/").arg(libextra);
+        }
     #endif
         foreach(const QString& lib, libs) {
             d->appendDir( appPath + lib + QSTR_DRUMSTICK, result );
@@ -146,7 +151,7 @@ namespace drumstick { namespace rt {
 
     /**
      * @brief BackendManager::refresh finds the installed backends applying the provided settings.
-     * @param settings
+     * @param settings Program settings
      */
     void BackendManager::refresh(QSettings *settings)
     {
@@ -164,7 +169,7 @@ namespace drumstick { namespace rt {
     /**
      * @brief BackendManager::refresh finds the installed backends searching the list of paths
      * provided by the function defaultPaths() applying the provided settings map as well.
-     * @param map
+     * @param map Program settings relevant section
      */
     void BackendManager::refresh(const QVariantMap &map)
     {
