@@ -11,7 +11,7 @@
         <location filename="../pianopalette.cpp" line="354"/>
         <location filename="../pianopalette.cpp" line="365"/>
         <source>N</source>
-        <translation type="unfinished"></translation>
+        <translation>N</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="144"/>
@@ -21,103 +21,103 @@
         <location filename="../pianopalette.cpp" line="355"/>
         <location filename="../pianopalette.cpp" line="366"/>
         <source>#</source>
-        <translation type="unfinished"></translation>
+        <translation>#</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="154"/>
         <location filename="../pianopalette.cpp" line="308"/>
         <source>1</source>
-        <translation type="unfinished"></translation>
+        <translation>1</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="155"/>
         <location filename="../pianopalette.cpp" line="309"/>
         <source>2</source>
-        <translation type="unfinished"></translation>
+        <translation>2</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="156"/>
         <location filename="../pianopalette.cpp" line="310"/>
         <source>3</source>
-        <translation type="unfinished"></translation>
+        <translation>3</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="157"/>
         <location filename="../pianopalette.cpp" line="311"/>
         <source>4</source>
-        <translation type="unfinished"></translation>
+        <translation>4</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="158"/>
         <location filename="../pianopalette.cpp" line="312"/>
         <source>5</source>
-        <translation type="unfinished"></translation>
+        <translation>5</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="159"/>
         <location filename="../pianopalette.cpp" line="313"/>
         <source>6</source>
-        <translation type="unfinished"></translation>
+        <translation>6</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="160"/>
         <location filename="../pianopalette.cpp" line="314"/>
         <source>7</source>
-        <translation type="unfinished"></translation>
+        <translation>7</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="161"/>
         <location filename="../pianopalette.cpp" line="315"/>
         <source>8</source>
-        <translation type="unfinished"></translation>
+        <translation>8</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="162"/>
         <location filename="../pianopalette.cpp" line="316"/>
         <source>9</source>
-        <translation type="unfinished"></translation>
+        <translation>9</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="163"/>
         <location filename="../pianopalette.cpp" line="317"/>
         <source>10</source>
-        <translation type="unfinished"></translation>
+        <translation>10</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="164"/>
         <location filename="../pianopalette.cpp" line="318"/>
         <source>11</source>
-        <translation type="unfinished"></translation>
+        <translation>11</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="165"/>
         <location filename="../pianopalette.cpp" line="319"/>
         <source>12</source>
-        <translation type="unfinished"></translation>
+        <translation>12</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="166"/>
         <location filename="../pianopalette.cpp" line="320"/>
         <source>13</source>
-        <translation type="unfinished"></translation>
+        <translation>13</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="167"/>
         <location filename="../pianopalette.cpp" line="321"/>
         <source>14</source>
-        <translation type="unfinished"></translation>
+        <translation>14</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="168"/>
         <location filename="../pianopalette.cpp" line="322"/>
         <source>15</source>
-        <translation type="unfinished"></translation>
+        <translation>15</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="169"/>
         <location filename="../pianopalette.cpp" line="323"/>
         <source>16</source>
-        <translation type="unfinished"></translation>
+        <translation>16</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="194"/>
@@ -147,7 +147,7 @@
         <location filename="../pianopalette.cpp" line="198"/>
         <location filename="../pianopalette.cpp" line="337"/>
         <source>E</source>
-        <translation>me</translation>
+        <translation>mi</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="199"/>
@@ -195,79 +195,79 @@
         <location filename="../pianopalette.cpp" line="228"/>
         <location filename="../pianopalette.cpp" line="367"/>
         <source>N*</source>
-        <translation type="unfinished"></translation>
+        <translation>N*</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="229"/>
         <location filename="../pianopalette.cpp" line="368"/>
         <source>#*</source>
-        <translation type="unfinished"></translation>
+        <translation>#*</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="241"/>
         <source>Single color highlight</source>
-        <translation type="unfinished"></translation>
+        <translation>Evidenziazione a colore singolo</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="242"/>
         <source>A single color to highlight all note events</source>
-        <translation type="unfinished"></translation>
+        <translation>Un singolo colore per evidenziare tutti gli eventi-nota</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="246"/>
         <source>Two colors highlight</source>
-        <translation type="unfinished"></translation>
+        <translation>Evidenziazione a due colori</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="247"/>
         <source>One color to highlight natural notes and a different one for accidentals</source>
-        <translation type="unfinished"></translation>
+        <translation>Un colore per evidenziare le note naturali e uno differente per gli accidenti</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="251"/>
         <source>MIDI Channels highlight</source>
-        <translation type="unfinished"></translation>
+        <translation>Evidenziazione dei canali MIDI</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="252"/>
         <source>A different color to highlight each MIDI channel. Enable Omni mode in the MIDI IN connection</source>
-        <translation type="unfinished"></translation>
+        <translation>Un colore diverso per evidenziare ogni canale MIDI. Abilita il modo Omni nella connessione MIDI IN</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="256"/>
         <source>Chromatic scale background</source>
-        <translation type="unfinished"></translation>
+        <translation>Sfondo della scala cromatica</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="257"/>
         <location filename="../pianopalette.cpp" line="272"/>
         <source>One color for each note in the chromatic scale</source>
-        <translation type="unfinished"></translation>
+        <translation>Un colore per ogni nota della scala cromatica</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="261"/>
         <source>Keys background</source>
-        <translation type="unfinished"></translation>
+        <translation>Sfondo dei tasti</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="262"/>
         <source>One color for natural notes and another for accidentals</source>
-        <translation type="unfinished"></translation>
+        <translation>Un colore per le note naturali e un altro per gli accidenti</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="266"/>
         <source>Font foreground</source>
-        <translation type="unfinished"></translation>
+        <translation>Colore del carattere</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="267"/>
         <source>Colors for note names</source>
-        <translation type="unfinished"></translation>
+        <translation>Colore dei nomi delle note</translation>
     </message>
     <message>
         <location filename="../pianopalette.cpp" line="271"/>
         <source>Chromatic scale highlight</source>
-        <translation type="unfinished"></translation>
+        <translation>Evidenziazione della scala cromatica</translation>
     </message>
 </context>
 <context>
@@ -275,107 +275,107 @@
     <message>
         <location filename="../fluidsettingsdialog.ui" line="14"/>
         <source>FluidSynth Driver Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Impostazioni del driver Fuidsynth</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.ui" line="123"/>
         <source>Sample Rate:</source>
-        <translation type="unfinished"></translation>
+        <translation>Tasso di campionamento:</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.ui" line="106"/>
         <source>Period Size:</source>
-        <translation type="unfinished"></translation>
+        <translation>Dimensione del periodo:</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.ui" line="159"/>
         <source># of Periods:</source>
-        <translation type="unfinished"></translation>
+        <translation># di Periodi:</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.ui" line="39"/>
         <source>Audio Driver:</source>
-        <translation type="unfinished"></translation>
+        <translation>Driver audio:</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.ui" line="169"/>
         <source>Polyphony:</source>
-        <translation type="unfinished"></translation>
+        <translation>Polifonia:</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.ui" line="89"/>
         <source>FluidSynth Version:</source>
-        <translation type="unfinished"></translation>
+        <translation>Versione di Fluidsynth:</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.ui" line="69"/>
         <source>Sound Font:</source>
-        <translation type="unfinished"></translation>
+        <translation>Banco di campioni:</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.ui" line="116"/>
         <source>Initialization Status:</source>
-        <translation type="unfinished"></translation>
+        <translation>Stato di inizializzazione:</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.ui" line="185"/>
         <source>Buffer Time:</source>
-        <translation type="unfinished"></translation>
+        <translation>Durata del buffer:</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.ui" line="192"/>
         <source> ms</source>
-        <translation type="unfinished"></translation>
+        <translation> ms</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.ui" line="49"/>
         <source>Gain:</source>
-        <translation type="unfinished"></translation>
+        <translation>Guadagno:</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.ui" line="152"/>
         <source>...</source>
-        <translation type="unfinished"></translation>
+        <translation>...</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.ui" line="139"/>
         <source>Chorus</source>
-        <translation type="unfinished"></translation>
+        <translation>Coro</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.ui" line="62"/>
         <source>Reverb</source>
-        <translation type="unfinished"></translation>
+        <translation>Riverbero</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.cpp" line="141"/>
         <source>FluidSynth Initialized</source>
-        <translation type="unfinished"></translation>
+        <translation>FluidSynth inizializzato</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.cpp" line="141"/>
         <source>FluidSynth Initialization Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Inizializzazione di FluidSynth fallita</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.cpp" line="204"/>
         <source>Ready</source>
-        <translation type="unfinished"></translation>
+        <translation>Pronto</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.cpp" line="204"/>
         <source>Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Errore</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.cpp" line="345"/>
         <source>Select SoundFont</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleziona un campione audio</translation>
     </message>
     <message>
         <location filename="../fluidsettingsdialog.cpp" line="345"/>
         <source>SoundFont Files (*.sf2 *.sf3 *.dls)</source>
-        <translation type="unfinished"></translation>
+        <translation>File di campioni audio (*.sf2 *.sf3 *.dls)</translation>
     </message>
 </context>
 <context>
@@ -383,62 +383,62 @@
     <message>
         <location filename="../macsynthsettingsdialog.ui" line="14"/>
         <source>macOS Synth Driver Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Impostazioni del Synth driver macOS</translation>
     </message>
     <message>
         <location filename="../macsynthsettingsdialog.ui" line="56"/>
         <source>SoundFont:</source>
-        <translation type="unfinished"></translation>
+        <translation>Banco di campioni:</translation>
     </message>
     <message>
         <location filename="../macsynthsettingsdialog.ui" line="76"/>
         <source>...</source>
-        <translation type="unfinished"></translation>
+        <translation>...</translation>
     </message>
     <message>
         <location filename="../macsynthsettingsdialog.ui" line="83"/>
         <source>Use Internal Reverb</source>
-        <translation type="unfinished"></translation>
+        <translation>Usa Riverbero interno</translation>
     </message>
     <message>
         <location filename="../macsynthsettingsdialog.ui" line="90"/>
         <source>Init. Status:</source>
-        <translation type="unfinished"></translation>
+        <translation>Stato di inizializzazione:</translation>
     </message>
     <message>
         <location filename="../macsynthsettingsdialog.ui" line="69"/>
         <source>Default Apple DLS Sound Set</source>
-        <translation type="unfinished"></translation>
+        <translation>Apple DLS set di souni di default</translation>
     </message>
     <message>
         <location filename="../macsynthsettingsdialog.cpp" line="72"/>
         <source>DLS Synth Initialized</source>
-        <translation type="unfinished"></translation>
+        <translation>DLS Synth inizializzato</translation>
     </message>
     <message>
         <location filename="../macsynthsettingsdialog.cpp" line="72"/>
         <source>DLS Synth Initialization Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Inizializzazione di DLS Synth fallita</translation>
     </message>
     <message>
         <location filename="../macsynthsettingsdialog.cpp" line="122"/>
         <source>Ready</source>
-        <translation type="unfinished"></translation>
+        <translation>Pronto</translation>
     </message>
     <message>
         <location filename="../macsynthsettingsdialog.cpp" line="122"/>
         <source>Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Errore</translation>
     </message>
     <message>
         <location filename="../macsynthsettingsdialog.cpp" line="163"/>
         <source>Select SoundFont</source>
-        <translation type="unfinished"></translation>
+        <translation>Selezionare un campione audio</translation>
     </message>
     <message>
         <location filename="../macsynthsettingsdialog.cpp" line="163"/>
         <source>SoundFont Files (*.sf2 *.dls)</source>
-        <translation type="unfinished"></translation>
+        <translation>File di campioni audio (*.sf2 *.dls)</translation>
     </message>
 </context>
 <context>
@@ -446,53 +446,53 @@
     <message>
         <location filename="../networksettingsdialog.ui" line="14"/>
         <source>Network Driver Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Impostrazioni del driver di network</translation>
     </message>
     <message>
         <location filename="../networksettingsdialog.ui" line="33"/>
         <source>Init. Status:</source>
-        <translation type="unfinished"></translation>
+        <translation>Stato di inizializzazione:</translation>
     </message>
     <message>
         <location filename="../networksettingsdialog.ui" line="50"/>
         <source>Use IPv6</source>
-        <translation type="unfinished"></translation>
+        <translation>Usa IPv6</translation>
     </message>
     <message>
         <location filename="../networksettingsdialog.ui" line="57"/>
         <source>Network Interface:</source>
-        <translation type="unfinished"></translation>
+        <translation>Interfaccia di network:</translation>
     </message>
     <message>
         <location filename="../networksettingsdialog.ui" line="70"/>
         <source>Address</source>
-        <translation type="unfinished"></translation>
+        <translation>Indirizzo</translation>
     </message>
     <message>
         <location filename="../networksettingsdialog.cpp" line="76"/>
         <source>Network Initialized</source>
-        <translation type="unfinished"></translation>
+        <translation>Network inizializzato</translation>
     </message>
     <message>
         <location filename="../networksettingsdialog.cpp" line="76"/>
         <source>Network Initialization Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Inizializzazione del network fallita</translation>
     </message>
     <message>
         <location filename="../networksettingsdialog.cpp" line="111"/>
         <location filename="../networksettingsdialog.cpp" line="174"/>
         <source>Any</source>
-        <translation type="unfinished"></translation>
+        <translation>Qualsiasi</translation>
     </message>
     <message>
         <location filename="../networksettingsdialog.cpp" line="164"/>
         <source>Ready</source>
-        <translation type="unfinished"></translation>
+        <translation>Pronto</translation>
     </message>
     <message>
         <location filename="../networksettingsdialog.cpp" line="164"/>
         <source>Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Errore</translation>
     </message>
 </context>
 <context>
@@ -572,7 +572,7 @@
     <message>
         <location filename="../pianoscene.cpp" line="1274"/>
         <source>E♭</source>
-        <translation>mim♭</translation>
+        <translation>mi♭</translation>
     </message>
     <message>
         <location filename="../pianoscene.cpp" line="1277"/>
@@ -595,52 +595,52 @@
     <message>
         <location filename="../sonivoxsettingsdialog.ui" line="14"/>
         <source>Sonivox EAS Synth</source>
-        <translation type="unfinished"></translation>
+        <translation>Sonivox EAS Synth</translation>
     </message>
     <message>
         <location filename="../sonivoxsettingsdialog.ui" line="26"/>
         <source>Chorus</source>
-        <translation type="unfinished"></translation>
+        <translation>Coro</translation>
     </message>
     <message>
         <location filename="../sonivoxsettingsdialog.ui" line="43"/>
         <source>Reverb</source>
-        <translation type="unfinished"></translation>
+        <translation>Reverbero</translation>
     </message>
     <message>
         <location filename="../sonivoxsettingsdialog.ui" line="71"/>
         <source>Buffer Time:</source>
-        <translation type="unfinished"></translation>
+        <translation>Durata del buffer:</translation>
     </message>
     <message>
         <location filename="../sonivoxsettingsdialog.ui" line="81"/>
         <source> ms</source>
-        <translation type="unfinished"></translation>
+        <translation> ms</translation>
     </message>
     <message>
         <location filename="../sonivoxsettingsdialog.ui" line="110"/>
         <source>Init. Status:</source>
-        <translation type="unfinished"></translation>
+        <translation>Stato di inizializzazione:</translation>
     </message>
     <message>
         <location filename="../sonivoxsettingsdialog.cpp" line="85"/>
         <source>Sonivox Initialized</source>
-        <translation type="unfinished"></translation>
+        <translation>Sonivox inizializzato</translation>
     </message>
     <message>
         <location filename="../sonivoxsettingsdialog.cpp" line="85"/>
         <source>Sonivox Initialization Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Inizializzazione di Sonivox fallita</translation>
     </message>
     <message>
         <location filename="../sonivoxsettingsdialog.cpp" line="165"/>
         <source>Ready</source>
-        <translation type="unfinished"></translation>
+        <translation>Pronto</translation>
     </message>
     <message>
         <location filename="../sonivoxsettingsdialog.cpp" line="165"/>
         <source>Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Errore</translation>
     </message>
 </context>
 </TS>
