@@ -1,6 +1,6 @@
 /*
     Virtual Piano test using the MIDI Sequencer C++ library 
-    Copyright (C) 2006-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2023, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 
 const char* PGM_DESCRIPTION = QT_TRANSLATE_NOOP("main",
      "Drumstick Simple Virtual Piano\n"
-     "Copyright (C) 2006-2022 Pedro Lopez-Cabanillas\n"
+     "Copyright (C) 2006-2023 Pedro Lopez-Cabanillas\n"
      "This program comes with ABSOLUTELY NO WARRANTY; "
      "This is free software, and you are welcome to redistribute it "
      "under certain conditions; see the LICENSE file for details.");
@@ -60,7 +60,7 @@ Q_IMPORT_PLUGIN(DummyOutput)
 #endif
 
 #if defined(FLUIDSYNTH_BACKEND)
-Q_IMPORT_PLUGIN(SynthOutput)
+Q_IMPORT_PLUGIN(FluidSynthOutput)
 #endif
 
 #if defined(OSS_BACKEND)
@@ -77,11 +77,18 @@ int main(int argc, char *argv[])
     QCoreApplication::setApplicationVersion(QStringLiteral(QT_STRINGIFY(VERSION)));
     QCoreApplication::setAttribute(Qt::AA_SynthesizeMouseForUnhandledTouchEvents, false);
     QCoreApplication::setAttribute(Qt::AA_SynthesizeTouchForUnhandledMouseEvents, false);
+    QGuiApplication::setDesktopFileName("net.sourceforge.drumstick-vpiano");
 
     QLocale locale;
     QTranslator qtTranslator;
     if ((locale.language() != QLocale::C) && (locale.language() != QLocale::English)) {
-        if (qtTranslator.load(locale, "qt", "_", QLibraryInfo::location(QLibraryInfo::TranslationsPath))) {
+        QString qtTranslations =
+            #if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
+                QLibraryInfo::location(QLibraryInfo::TranslationsPath);
+            #else
+                QLibraryInfo::path(QLibraryInfo::TranslationsPath);
+            #endif
+        if (qtTranslator.load(locale, "qt", "_", qtTranslations)) {
             if (!QCoreApplication::installTranslator(&qtTranslator)) {
                 qWarning() << "Failure installing qt translator" << locale;
             }
